@@ -27,6 +27,9 @@
 --
 --
 -- $Log: combine_backup_files.c,v $
+-- Revision 1.5  2008/05/19 03:53:29  jsedwards
+-- Increased the MAX_FILES to 100 from 64.
+--
 -- Revision 1.4  2007/11/18 13:25:45  jsedwards
 -- Fix error test of return value from read_next_file_chunk.
 --
@@ -50,7 +53,7 @@
 #include "objectify_private.h"
 
 
-#define MAX_FILES 64
+#define MAX_FILES 100
 #define MAX_BUFFER_SIZE 1048576
 #define MAX_BLOCKS (MAX_BUFFER_SIZE / FILE_BLOCK_SIZE)
 
