@@ -27,6 +27,10 @@
 --
 --
 -- $Log: disk_io.c,v $
+-- Revision 1.85  2008/06/26 14:54:30  jsedwards
+-- Change so that if initialize backup fails, it shuts disk_io down again and
+-- exits.
+--
 -- Revision 1.84  2008/06/12 02:16:29  jsedwards
 -- Fixed so that read_only flag is not set in PUBLIC_MODE, because if it is
 -- set no backup file gets written.
@@ -940,7 +944,11 @@ void nwos_initialize_disk_io(AccessType type, const char* path)
 
     if (backup_dir != NULL && !read_only)
     {
-	nwos_initialize_backup(backup_dir, &nwos_disk_header);
+	if (!nwos_initialize_backup(backup_dir, &nwos_disk_header))    /* creating backup failed, shut 'er back down */
+	{
+	    nwos_terminate_disk_io();
+	    exit(1);
+	}
     }
 #endif
 }
