@@ -27,6 +27,10 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.30  2008/06/04 14:03:15  jsedwards
+-- Added code to alert user to run the 'update_files_0028' program if
+-- compressed file is older than 0028.
+--
 -- Revision 1.29  2008/03/16 14:12:39  jsedwards
 -- Fixed problem where it would print warning about compatible compressed file
 -- version even when it was the correct version.
@@ -199,6 +203,7 @@ int main(int argc, char* argv[])
 #endif
     char answer[8];
     char msg[128];
+    bool pre_0028 = false;
 
 
     if (argc != 2)
@@ -304,6 +309,8 @@ int main(int argc, char* argv[])
 	}
 
 	/* if old versions need special handling put it here and remove braces below */ 
+
+	if (memcmp(&block[4], "0028", 4) < 0) pre_0028 = true;   /* need to warn at the end */
     }
     else
     {
@@ -396,6 +403,16 @@ int main(int argc, char* argv[])
 	fprintf(stderr, "%s\n", msg);
     }
 
+    if (pre_0028)
+    {
+	fprintf(stderr, "\n");
+	fprintf(stderr, "******************************************************************************\n");
+	fprintf(stderr, " WARNING: compressed file is older than version Alpha_28, you need to run the\n");
+	fprintf(stderr, " 'update_files_0028' program to move the revision links to the correct place.\n");
+	fprintf(stderr, "******************************************************************************\n");
+	fprintf(stderr, "\n");
+    }
+
     return 0;
 }
 
