@@ -27,6 +27,9 @@
 --
 --
 -- $Log: import_file.c,v $
+-- Revision 1.36  2008/07/11 13:01:05  jsedwards
+-- Added include of limits.h to define PATH_MAX.
+--
 -- Revision 1.35  2008/06/23 13:40:18  jsedwards
 -- Fixed to remove the leading "./" from the path if doing "-r .".
 --
@@ -165,6 +168,7 @@
 
 #include <assert.h>
 #include <dirent.h>
+#include <limits.h>    /* define PATH_MAX */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
