@@ -27,6 +27,23 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.140  2008/06/22 18:57:06  jsedwards
+-- Changed nwos_normalize_path to return void instead of bool.
+--
+-- Revision 1.139  2008/06/21 16:10:42  jsedwards
+-- Added external declaration for nwos_normalize_path.
+--
+-- Revision 1.138  2008/06/19 13:07:41  jsedwards
+-- Added 'allow_multiple_paths' parameter to nwos_create_file declaration.
+--
+-- Revision 1.137  2008/06/12 03:23:17  jsedwards
+-- Added external declarations for 'nwos_check_invalid_type' and
+-- 'nwos_check_directory_is_all_ok'.
+--
+-- Revision 1.136  2008/04/26 11:10:42  jsedwards
+-- Added 'const' to functions with 'char*' parameters in log.c, file.c and
+-- name.c.
+--
 -- Revision 1.135  2008/03/20 13:09:40  jsedwards
 -- Added external declaration for nwos_in_public_mode().
 --
@@ -890,10 +907,10 @@ extern void   nwos_encode_variable_sized_count(uint32 count, uint8 result[4]);
 
 extern void nwos_log(char* str);
 extern void nwos_log_arguments(int argc, char* argv[]);
-extern void nwos_log_md5sum(char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE]);
-extern void nwos_log_sha1sum(char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE]);
-extern void nwos_log_sha256sum(char* file_name, uint8 sha256_digest[SHA256_DIGEST_SIZE]);
-extern void nwos_log_sha512sum(char* file_name, uint8 sha512_digest[SHA512_DIGEST_SIZE]);
+extern void nwos_log_md5sum(const char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE]);
+extern void nwos_log_sha1sum(const char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE]);
+extern void nwos_log_sha256sum(const char* file_name, uint8 sha256_digest[SHA256_DIGEST_SIZE]);
+extern void nwos_log_sha512sum(const char* file_name, uint8 sha512_digest[SHA512_DIGEST_SIZE]);
 
 extern void nwos_initialize_objectify(uint8 bf_key[16], uint32 linear, uint32 serial, AccessType type, const char* path);
 extern void nwos_terminate_objectify();
@@ -935,7 +952,7 @@ extern void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size);
 extern void nwos_read_variable_sized_object_from_disk(ObjRef* ref, void* obj, size_t max_size, size_t (*size_function)(void*));
 extern void nwos_read_reference_list_from_disk(ObjRef* ref, ReferenceList* object, size_t size);
 
-typedef enum { CREATED_NEW, CREATED_NEW_REVISION, FOUND_EXISTING, ERROR_OCCURRED, DUPLICATE_PATH, DUPLICATE_FILE, PATH_NOT_FOUND, MULTIPLE_FILES, NUM_OBJ_RESULTS } ObjCreateResult;
+typedef enum { CREATED_NEW, CREATED_NEW_REVISION, FOUND_EXISTING, ERROR_OCCURRED, DUPLICATE_PATH, DUPLICATE_FILE, PATH_NOT_FOUND, MULTIPLE_FILES, CREATED_NEW_PATH_FOR_EXISTING_FILE, NUM_OBJ_RESULTS } ObjCreateResult;
 
 
 
@@ -961,9 +978,9 @@ extern bool nwos_ask_yes_or_no(char* statement, char* question);
 
 
 /* name stuff */
-extern bool            nwos_find_public_name(char* name, ObjRef* ref);
-extern bool            nwos_find_private_name(char* name, ObjRef* ref);
-extern ObjCreateResult nwos_create_name(char* name, ObjRef* ref);
+extern bool            nwos_find_public_name(const char* name, ObjRef* ref);
+extern bool            nwos_find_private_name(const char* name, ObjRef* ref);
+extern ObjCreateResult nwos_create_name(const char* name, ObjRef* ref);
 extern bool            nwos_name_to_string(ObjRef* ref, char* string, size_t size);
 
 /* date stuff */
@@ -1038,27 +1055,30 @@ extern bool nwos_url_to_string(ObjRef* ref, char* string, size_t size);
 
 extern void nwos_list_public_credit_unions();
 
-extern bool nwos_find_file_path(char* path, ObjRef* ref);
-extern ObjCreateResult nwos_create_file_path(char* path, ObjRef* ref);
+extern void nwos_normalize_path(char* dst, char* src, size_t size);
+extern bool nwos_find_file_path(const char* path, ObjRef* ref);
+extern ObjCreateResult nwos_create_file_path(const char* path, ObjRef* ref);
 extern bool nwos_file_path_to_string(ObjRef* ref, char* string, size_t size);
 extern int  nwos_number_of_files_for_path(ObjRef* path_ref);
-extern uint32 nwos_estimate_blocks_for_file(char* path);
+extern uint32 nwos_estimate_blocks_for_file(const char* path);
 extern bool nwos_file_path_to_path_and_file_association(ObjRef* path_ref, int index, ObjRef* assoc_ref);
 extern bool nwos_find_md5(uint8 md5[16], ObjRef* ref);
 extern bool nwos_find_path_and_file_association(ObjRef* path_ref, ObjRef* file_ref, TimeStamp mod_time, ObjRef* ref);
 typedef enum { MatchAll, IgnoreTime } MatchCode;
-extern bool nwos_find_matching_path_and_file_association(char* path, char* file, ObjRef* ref, MatchCode match);
-extern CheckFileResult nwos_check_file_checksums(char* path);
+extern bool nwos_find_matching_path_and_file_association(const char* path, const char* file, ObjRef* ref, MatchCode match);
+extern CheckFileResult nwos_check_file_checksums(const char* path);
 extern bool nwos_file_is_stored(ObjRef* association_ref);  /* returns true if data stored in system */
 extern bool nwos_file_has_backup(ObjRef* association_ref);  /* returns true if file is on a backup disc */
-extern ObjCreateResult nwos_create_file_with_only_md5(char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE], ObjRef* ref);
-extern ObjCreateResult nwos_add_info_to_existing_file(char* file_name, ObjRef* ref);
-extern ObjCreateResult nwos_create_file_without_storing_data(char* path, char* file_name, ObjRef* ref);
-extern ObjCreateResult nwos_create_file(char* path, ObjRef* ref);
-extern ObjCreateResult nwos_add_new_revision_of_file(char* path, ObjRef* ref);
+extern ObjCreateResult nwos_create_file_with_only_md5(const char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_add_info_to_existing_file(const char* file_name, ObjRef* ref);
+extern ObjCreateResult nwos_create_file_without_storing_data(const char* path, const char* file_name, ObjRef* ref);
+extern ObjCreateResult nwos_create_file(const char* path, ObjRef* ref, bool allow_multiple_paths);
+extern ObjCreateResult nwos_add_new_revision_of_file(const char* path, ObjRef* ref);
 extern ObjCreateResult nwos_find_or_create_path_and_file_association(ObjRef* path_ref, ObjRef* file_ref, TimeStamp mod_time, ObjRef* ref);
-extern bool nwos_restore_file(ObjRef* file_ref, char* path);
-extern bool nwos_file_is_identical(ObjRef* assoc_ref, char* path, MatchCode match);
+extern bool nwos_restore_file(ObjRef* file_ref, const char* path);
+extern bool nwos_file_is_identical(ObjRef* assoc_ref, const char* path, MatchCode match);
+extern const char* nwos_check_invalid_type(mode_t mode);
+extern void nwos_check_directory_is_all_ok(const char* path);
 
 #define MAX_FILES_PER_DISC_LIST 4096
 #define MAX_SIZE_DISC_LIST (sizeof(C_struct_Disc_List) + sizeof(ObjRef) * MAX_FILES_PER_DISC_LIST)
@@ -1068,8 +1088,8 @@ extern bool nwos_find_matching_disc_list(ObjRef files[MAX_FILES_PER_DISC_LIST],
 extern ObjCreateResult nwos_create_disc_list(char id[12], ObjRef disc_list[MAX_FILES_PER_DISC_LIST], ObjRef* ref);
 extern bool nwos_find_disc_copy(ObjRef* disc_list, int copy_num, ObjRef* ref);
 extern ObjCreateResult nwos_create_disc_copy(ObjRef* disc_list, int copy_num, ObjRef* location, ObjRef* ref);
-extern bool nwos_find_storage_location(char* location, ObjRef* ref);
-extern ObjCreateResult nwos_create_storage_location(char* location, ObjRef* ref);
+extern bool nwos_find_storage_location(const char* location, ObjRef* ref);
+extern ObjCreateResult nwos_create_storage_location(const char* location, ObjRef* ref);
 
 extern bool nwos_is_valid_ssn(const char* ssn);
 
