@@ -27,6 +27,12 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.67  2008/06/26 14:50:26  jsedwards
+-- Changed nwos_initialize_backup to return bool instead of void.
+--
+-- Revision 1.66  2008/05/22 11:32:26  jsedwards
+-- Added external declaration for nwos_disk_header.
+--
 -- Revision 1.65  2008/05/06 13:28:51  jsedwards
 -- Changed return type of nwos_read_object_from_disk_and_decrypt to bool
 -- instead of void.
@@ -384,6 +390,8 @@ typedef struct {
     uint8 unused7[4];
 } Disk_Header_0016_to_0020;
 
+extern Disk_Header nwos_disk_header;
+
 extern uint32 nwos_total_public_blocks;
 extern uint32 nwos_total_private_blocks;
 extern uint32 nwos_used_public_blocks;
@@ -480,7 +488,7 @@ extern const char* nwos_public_path;
 extern const char* nwos_private_path;
 extern void  nwos_initialize_disk_io(AccessType type, const char* path);
 extern void  nwos_terminate_disk_io();
-extern void  nwos_initialize_backup(const char* path, Disk_Header* disk_header);
+extern bool  nwos_initialize_backup(const char* path, Disk_Header* disk_header);
 extern void  nwos_terminate_backup(bool modified, Disk_Header* disk_header);
 extern void  nwos_backup_write_block(uint8 block[FILE_BLOCK_SIZE]);
 extern void  nwos_set_allocation_parameters(uint32 density, int32 skip_backward, int32 skip_forward);
